#!/bin/bash

set -e

CMD="$@"

# check if docker installed and running
docker info &>/dev/null || (echo "WARNING: Xray requires Docker daemon UP and running" && exit 1)

XRAY_VERSION="1.7.2.3"
DOCKER_SERVER_CURRENT_VER=$(docker version --format '{{.Server.Version}}' 2>/dev/null) || DOCKER_SERVER_CURRENT_VER=""

# Xray installer workdir
XRAY_DIR="${HOME}/.jfrog/xray/xray-installer"

# Xray installer conf file, should be created in the first run
XRAY_CONF="${XRAY_DIR}/xray-env.conf"

XRAY_MOUNT_ROOT_DEFAULT="${HOME}/.jfrog/xray"

[ ! -d "$XRAY_DIR" ] && mkdir -p "$XRAY_DIR"

# Create the installer configuration file
if [ ! -f "$XRAY_CONF" ]; then
    echo -e "\nXRAY_MOUNT_ROOT must be set on xray first installation \nPlease type desired XRAY_MOUNT_ROOT location"

    read -p "Enter mount root [${XRAY_MOUNT_ROOT_DEFAULT}]: " XRAY_MOUNT_ROOT
    XRAY_MOUNT_ROOT=${XRAY_MOUNT_ROOT:-${XRAY_MOUNT_ROOT_DEFAULT}}

    # Write to conf file
    echo "export XRAY_MOUNT_ROOT=${XRAY_MOUNT_ROOT}" >> ${XRAY_CONF}
    echo "XRAY_MOUNT_ROOT is now specified in ${XRAY_CONF}, as ${XRAY_MOUNT_ROOT}"
fi

# Load the installer configuration file
if [ -f "$XRAY_CONF" ]; then
    source "${XRAY_CONF}"
else
    echo "ERROR: configuration file does not exist [${XRAY_CONF}]"
    exit 1
fi

if [ -z ${XRAY_MOUNT_ROOT} ]
then
    echo "ERROR: XRAY_MOUNT_ROOT is not set, please update the conf file [${XRAY_CONF}]"
    exit 1
fi
echo "INFO: Using XRAY_MOUNT_ROOT=${XRAY_MOUNT_ROOT}"

# Setup options for connecting to docker host
if [ -z "$DOCKER_HOST" ]; then
    DOCKER_HOST="/var/run/docker.sock"
fi
if [ -S "$DOCKER_HOST" ]; then
    DOCKER_ADDR="-v $DOCKER_HOST:$DOCKER_HOST -e DOCKER_HOST"
else
    DOCKER_ADDR="-e DOCKER_HOST -e DOCKER_TLS_VERIFY -e DOCKER_CERT_PATH"
fi

# Only allocate tty if we detect one
if [ -t 1 ]; then
    DOCKER_RUN_OPTIONS="-t"
fi
if [ -t 0 ]; then
    DOCKER_RUN_OPTIONS="$DOCKER_RUN_OPTIONS -i"
fi

XRAY_VOLUMES="-v ${XRAY_MOUNT_ROOT}/xray-installer:/data -v ${XRAY_MOUNT_ROOT}:/xray_global_mount_root"

# set XRAY_LOCAL_DOCKER_REPO in XRAY_CONF to use local docker repo
XRAY_DOCKER_REPO=${XRAY_LOCAL_DOCKER_REPO:-"xray-docker-release.jfrog.info/jfrog"}
XRAYDB_DOCKER_REPO=${XRAY_LOCAL_DOCKER_REPO:-"docker.bintray.io/jfrog"}
DOCKER_INSTALLER_OFFLINE=${DOCKER_INSTALLER_OFFLINE:-"false"}

IMAGE="${XRAY_DOCKER_REPO}/xray-installer:$XRAY_VERSION"

# check if docker images exists locally in order to hide "Unable to find image locally" message
docker inspect ${IMAGE} &>/dev/null || docker pull ${IMAGE}

exec docker run --rm $DOCKER_RUN_OPTIONS $DOCKER_ADDR $XRAY_VOLUMES -e XRAY_DOCKER_REPO=$XRAY_DOCKER_REPO -e DOCKER_INSTALLER_OFFLINE=${DOCKER_INSTALLER_OFFLINE} -e XRAYDB_DOCKER_REPO=$XRAYDB_DOCKER_REPO -e XRAY_VERSION=$XRAY_VERSION -e SERVER_FLAG=$SERVER_FLAG -e XRAY_MOUNT_ROOT=$XRAY_MOUNT_ROOT -e DOCKER_SERVER_CURRENT_VER=$DOCKER_SERVER_CURRENT_VER $IMAGE "$CMD"

exit $?